==> foundation-2.6.1.tgz: package/SocialJoomla/SocialJoomla.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const SocialJoomla = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M81.433 68.316c-1.245-1.029-2.883-1.582-4.507-2.443 1.247-6.475-1.226-11.717-6.169-16.113-2.454-2.184-4.671-4.638-6.935-7.027-2.06-2.176-4.038-4.43-6.348-6.976l-6.986 7.634c.418.318.987.655 1.438 1.109 4.596 4.621 9.167 9.27 13.76 13.895 1.703 1.715 2.339 3.752 1.544 6.012-.786 2.234-2.489 3.82-4.891 3.749-1.728-.05-3.432-.926-5.163-1.438l-6.474 6.37c4.344 4.493 9.656 5.624 15.729 4.274.854 3.877 3.5 5.938 6.805 7.368h4.652c.324-.168.638-.363.975-.501 6.762-2.762 8.183-11.269 2.57-15.913z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M56.4 51.269c-.291.411-.625 1.066-1.122 1.559-4.63 4.592-9.271 9.173-13.943 13.722-2.322 2.261-5.26 2.342-7.651.31-2.307-1.962-2.666-5.088-.869-7.652.283-.403.6-.783.745-.971l-6.729-6.793c-4.257 4.049-5.51 9.106-4.458 14.934-4.266 1.211-6.417 4.191-7.282 8.273v1.938c.938 4.087 3.357 6.832 7.365 8.141h4.264c2.657-1.11 5.172-2.475 6.204-5.362.519-1.451 1.195-1.79 2.67-1.595 4.759.63 8.983-.766 12.37-4.129 5.173-5.138 10.189-10.435 15.56-15.96L56.4 51.269zM35.946 42.96l6.537 6.358c2.867-2.889 5.67-5.742 8.507-8.561 2.288-2.273 4.571-4.553 6.939-6.742 2.057-1.901 4.531-2.146 6.761-.85 2.125 1.235 3.316 3.697 2.677 6.104-.318 1.197-1.119 2.266-1.673 3.338l6.65 6.669c4.362-4.219 5.631-9.397 4.411-15.264 6.022-2.594 8.531-5.794 8.055-10.204-.457-4.231-3.475-7.902-7.386-8.341-1.958-.22-4.138.099-5.998.776-3.06 1.114-4.471 3.871-5.263 6.897-.565-.045-.955-.033-1.325-.112-4.585-.969-8.977-.134-12.308 2.989-5.727 5.372-11.017 11.207-16.584 16.943z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M22.564 33.799c-1.655 6.861.583 12.263 5.552 16.803 2.381 2.176 4.605 4.527 6.86 6.837 2.244 2.299 4.438 4.646 6.653 6.97l6.918-6.839c-.526-.554-1-1.065-1.489-1.563-4.568-4.649-9.164-9.274-13.7-13.955-2.186-2.256-2.243-5.441-.27-7.695 2.055-2.347 5.236-2.633 7.811-.705.34.255.69.496.633.455l6.786-6.805c-3.857-3.83-8.686-5.32-14.261-4.3-2.728-6.083-5.454-8.083-10.412-7.681-3.768.305-7.274 3.067-8.018 6.787-1.162 5.824 1.469 9.659 6.937 11.691z"
  }));
});
SocialJoomla.displayName = 'SocialJoomla';
export const SocialJoomlaDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/SocialJoomla/SocialJoomla.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var SocialJoomla = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M81.433 68.316c-1.245-1.029-2.883-1.582-4.507-2.443 1.247-6.475-1.226-11.717-6.169-16.113-2.454-2.184-4.671-4.638-6.935-7.027-2.06-2.176-4.038-4.43-6.348-6.976l-6.986 7.634c.418.318.987.655 1.438 1.109 4.596 4.621 9.167 9.27 13.76 13.895 1.703 1.715 2.339 3.752 1.544 6.012-.786 2.234-2.489 3.82-4.891 3.749-1.728-.05-3.432-.926-5.163-1.438l-6.474 6.37c4.344 4.493 9.656 5.624 15.729 4.274.854 3.877 3.5 5.938 6.805 7.368h4.652c.324-.168.638-.363.975-.501 6.762-2.762 8.183-11.269 2.57-15.913z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M56.4 51.269c-.291.411-.625 1.066-1.122 1.559-4.63 4.592-9.271 9.173-13.943 13.722-2.322 2.261-5.26 2.342-7.651.31-2.307-1.962-2.666-5.088-.869-7.652.283-.403.6-.783.745-.971l-6.729-6.793c-4.257 4.049-5.51 9.106-4.458 14.934-4.266 1.211-6.417 4.191-7.282 8.273v1.938c.938 4.087 3.357 6.832 7.365 8.141h4.264c2.657-1.11 5.172-2.475 6.204-5.362.519-1.451 1.195-1.79 2.67-1.595 4.759.63 8.983-.766 12.37-4.129 5.173-5.138 10.189-10.435 15.56-15.96L56.4 51.269zM35.946 42.96l6.537 6.358c2.867-2.889 5.67-5.742 8.507-8.561 2.288-2.273 4.571-4.553 6.939-6.742 2.057-1.901 4.531-2.146 6.761-.85 2.125 1.235 3.316 3.697 2.677 6.104-.318 1.197-1.119 2.266-1.673 3.338l6.65 6.669c4.362-4.219 5.631-9.397 4.411-15.264 6.022-2.594 8.531-5.794 8.055-10.204-.457-4.231-3.475-7.902-7.386-8.341-1.958-.22-4.138.099-5.998.776-3.06 1.114-4.471 3.871-5.263 6.897-.565-.045-.955-.033-1.325-.112-4.585-.969-8.977-.134-12.308 2.989-5.727 5.372-11.017 11.207-16.584 16.943z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M22.564 33.799c-1.655 6.861.583 12.263 5.552 16.803 2.381 2.176 4.605 4.527 6.86 6.837 2.244 2.299 4.438 4.646 6.653 6.97l6.918-6.839c-.526-.554-1-1.065-1.489-1.563-4.568-4.649-9.164-9.274-13.7-13.955-2.186-2.256-2.243-5.441-.27-7.695 2.055-2.347 5.236-2.633 7.811-.705.34.255.69.496.633.455l6.786-6.805c-3.857-3.83-8.686-5.32-14.261-4.3-2.728-6.083-5.454-8.083-10.412-7.681-3.768.305-7.274 3.067-8.018 6.787-1.162 5.824 1.469 9.659 6.937 11.691z"
  }));
});
SocialJoomla.displayName = 'SocialJoomla';
export var SocialJoomlaDimensions = {
  height: 100,
  width: 100
};
